@@ -1,10 +1,10 @@
 var classqx_1_1_qx_function__1 =
 [
-    [ "QxInvokerFct", "structqx_1_1_qx_function__1_1_1_qx_invoker_fct.html", "structqx_1_1_qx_function__1_1_1_qx_invoker_fct" ],
-    [ "QxInvokerFct< T, true >", "structqx_1_1_qx_function__1_1_1_qx_invoker_fct_3_01_t_00_01true_01_4.html", "structqx_1_1_qx_function__1_1_1_qx_invoker_fct_3_01_t_00_01true_01_4" ],
     [ "type_fct", "classqx_1_1_qx_function__1.html#aa1a837e03a6e850f95d82942982bba54", null ],
     [ "type_P1", "classqx_1_1_qx_function__1.html#ad8bda9e1deb9e7ec48790649a3bca6c3", null ],
     [ "getParamCount", "classqx_1_1_qx_function__1.html#a36bf9837effbbd2c434ee576a71b2d00", null ],
+    [ "invoke", "classqx_1_1_qx_function__1.html#a8e9f7675d27c19d8b347b53fa36ff39e", null ],
+    [ "invoke", "structqx_1_1_qx_function__1_1_1_qx_invoker_fct.html#a1c2c8fcc88465a135e324c511a2b6058", null ],
     [ "isValidParams", "classqx_1_1_qx_function__1.html#af36b8e7457755a219435128a3085884b", null ],
     [ "isValidParams", "classqx_1_1_qx_function__1.html#a28164e4fd9d703572ab81f557a81427c", null ],
     [ "QX_FUNCTION_CLASS_MEMBER_FCT", "classqx_1_1_qx_function__1.html#abf578da52f2ca2e082bea6579f1df42f", null ]
