@@ -1,7 +1,5 @@
 var classqx_1_1_qx_function__6 =
 [
-    [ "QxInvokerFct", "structqx_1_1_qx_function__6_1_1_qx_invoker_fct.html", "structqx_1_1_qx_function__6_1_1_qx_invoker_fct" ],
-    [ "QxInvokerFct< T, true >", "structqx_1_1_qx_function__6_1_1_qx_invoker_fct_3_01_t_00_01true_01_4.html", "structqx_1_1_qx_function__6_1_1_qx_invoker_fct_3_01_t_00_01true_01_4" ],
     [ "type_fct", "classqx_1_1_qx_function__6.html#a405bc628be5cf19565f163768a073f8b", null ],
     [ "type_P1", "classqx_1_1_qx_function__6.html#a62f534db16cb8cf0ca77b37f852a4cc1", null ],
     [ "type_P2", "classqx_1_1_qx_function__6.html#a6be19947c1b5492719888bd829c57a21", null ],
@@ -10,6 +8,8 @@ var classqx_1_1_qx_function__6 =
     [ "type_P5", "classqx_1_1_qx_function__6.html#a54fd478b0cdaae9729e9f5121c7e41f6", null ],
     [ "type_P6", "classqx_1_1_qx_function__6.html#a498b7564388fcad5e3e4ca1db3cc1bb6", null ],
     [ "getParamCount", "classqx_1_1_qx_function__6.html#a92dfa767580f8bb8f3251712a57d9216", null ],
+    [ "invoke", "classqx_1_1_qx_function__6.html#aabd6f776237596bb46dd1c234f2ad80a", null ],
+    [ "invoke", "structqx_1_1_qx_function__6_1_1_qx_invoker_fct.html#ad815ad1bd1d2beb6ac02a2b0ad016a2b", null ],
     [ "isValidParams", "classqx_1_1_qx_function__6.html#aa0ac46daa67373797312c4051d601b22", null ],
     [ "isValidParams", "classqx_1_1_qx_function__6.html#a49c08a10325b32e09cdb45063ca2ac4b", null ],
     [ "QX_FUNCTION_CLASS_MEMBER_FCT", "classqx_1_1_qx_function__6.html#aadc9c8781e0637c911075cf08b4cecfb", null ]
